"use strict";
/*
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates. All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.reInitialize = exports.useOnlyAlloyRegions = exports.doesAlloyConfigFileExist = exports.isOCIAlloyRegionCoexistEnabled = exports.isServiceEnabled = exports.alloyConfiguration = exports.getAlloyConfigFilePath = void 0;
const path_1 = __importDefault(require("path"));
const region_1 = require("./region");
const fs_1 = __importDefault(require("fs"));
const realm_1 = require("./realm");
const config_file_reader_1 = require("./config-file-reader");
const OCI_ALLOY_CONFIG_FILE_PATH = "OCI_ALLOY_CONFIG_FILE_PATH";
const OCI_ALLOY_REGION_COEXIST = "OCI_ALLOY_REGION_COEXIST";
const DEFAULT_ALLOY_CONFIG_FILE_PATH = config_file_reader_1.ConfigFileReader.expandUserHome(path_1.default.join("~", ".oci", "alloy-config.json"));
let ociRegionCoexist;
let ociAlloyProvider;
let ociEnabledServiceSet;
let alloyConfiguredRegions;
function getParsedServiceName(serviceName) {
    return serviceName.toLowerCase().replace("/[^a-z]/", "");
}
function getAlloyConfigFilePath() {
    var _a;
    return (_a = process.env.OCI_ALLOY_CONFIG_FILE_PATH) !== null && _a !== void 0 ? _a : DEFAULT_ALLOY_CONFIG_FILE_PATH;
}
exports.getAlloyConfigFilePath = getAlloyConfigFilePath;
function initializeAlloyConfiguration() {
    var _a, _b;
    // Initialize the OciEnabledServiceSet
    ociEnabledServiceSet = new Set();
    alloyConfiguredRegions = new Array();
    ociAlloyProvider = "";
    ociRegionCoexist = false;
    let configFilePath = getAlloyConfigFilePath();
    try {
        let content = fs_1.default.readFileSync(configFilePath, "utf8");
        if (!content) {
            return;
        }
        let alloyConfig;
        try {
            alloyConfig = JSON.parse(content);
        }
        catch (error) {
            console.log("Failure while parsing alloy config file: " + configFilePath + " ex:" + error);
        }
        if (alloyConfig !== undefined) {
            // Add configured services to OciEnabledServiceSet
            (_a = alloyConfig === null || alloyConfig === void 0 ? void 0 : alloyConfig.services) === null || _a === void 0 ? void 0 : _a.forEach((service) => {
                ociEnabledServiceSet.add(getParsedServiceName(service));
            });
            // Add configured Regions to AlloyConfiguredRegions
            (_b = alloyConfig === null || alloyConfig === void 0 ? void 0 : alloyConfig.regions) === null || _b === void 0 ? void 0 : _b.forEach((region) => {
                alloyConfiguredRegions.push(region);
            });
            // Initialize Alloy provider
            if (alloyConfig.alloyProvider !== null) {
                ociAlloyProvider = alloyConfig.alloyProvider;
            }
            // Initialize ociRegionCoexist from Alloy config
            if (alloyConfig.ociRegionCoexist !== null) {
                ociRegionCoexist = Boolean(alloyConfig.ociRegionCoexist);
            }
        }
    }
    catch (error) {
        if (error.code === "ENOENT") {
            console.log("Alloy config file not found at " +
                { configFilePath } +
                ", enabling all OCI services as default");
            return;
        }
        else {
            console.log("Enabling all OCI services as failsafe. There was an exception while trying to read or de-serialize the alloy config file at: " +
                configFilePath +
                " ex:" +
                error);
        }
    }
}
function alloyConfiguration() {
    initializeAlloyConfiguration();
}
exports.alloyConfiguration = alloyConfiguration;
function isServiceEnabled(service) {
    // Convert the service name to lower case to avoid match failure in list
    service = getParsedServiceName(service);
    if (ociEnabledServiceSet == null) {
        initializeAlloyConfiguration();
    }
    // If OciEnabledServiceSet is empty then we enable all services.
    if (ociEnabledServiceSet.size == 0) {
        console.log("The OciEnabledServiceSet is empty, all OCI services are enabled");
        return true;
    }
    return ociEnabledServiceSet.has(service);
}
exports.isServiceEnabled = isServiceEnabled;
function isOCIAlloyRegionCoexistEnabled() {
    var _a;
    let ociRegionCoexistFromEnvironmentVariable = Boolean((_a = process.env.OCI_ALLOY_REGION_COEXIST) !== null && _a !== void 0 ? _a : false);
    if (ociRegionCoexistFromEnvironmentVariable != null) {
        console.log("The environment variable OCI_ALLOY_REGION_COEXIST is set to " +
            ociRegionCoexistFromEnvironmentVariable);
        const result = Boolean(ociRegionCoexistFromEnvironmentVariable);
        return result;
    }
    return ociRegionCoexist;
}
exports.isOCIAlloyRegionCoexistEnabled = isOCIAlloyRegionCoexistEnabled;
function doesAlloyConfigFileExist() {
    return fs_1.default.existsSync(getAlloyConfigFilePath());
}
exports.doesAlloyConfigFileExist = doesAlloyConfigFileExist;
function useOnlyAlloyRegions() {
    return (!isOCIAlloyRegionCoexistEnabled() &&
        (doesAlloyConfigFileExist() || alloyConfiguredRegions.length != 0));
}
exports.useOnlyAlloyRegions = useOnlyAlloyRegions;
function reInitialize() {
    region_1.Region.resetAlloyConfig();
    realm_1.Realm.resetAlloyConfig();
    initializeAlloyConfiguration();
}
exports.reInitialize = reInitialize;
//# sourceMappingURL=alloyConfiguration.js.map